"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PAGE_ACTIONS = exports.PAGE_ROLE = exports.PAGE_AUTH = exports.PAGE_DATATABLE = exports.PAGE_SHOWBREADCRUMB = exports.PAGE_SHOWTITLE = exports.PAGE_TITLE = exports.PAGE_OUTPUT = exports.PAGE_FORM = exports.PAGE_ROUTER = exports.PAGE_SCHEMA = void 0;
exports.Page = Page;
exports.PAGE_SCHEMA = Symbol('page_schema');
exports.PAGE_ROUTER = Symbol('page_router');
exports.PAGE_FORM = Symbol('page_form');
exports.PAGE_OUTPUT = Symbol('page_output');
exports.PAGE_TITLE = Symbol('page_title');
exports.PAGE_SHOWTITLE = Symbol('page_showTitle');
exports.PAGE_SHOWBREADCRUMB = Symbol('page_showBreadcrumb');
exports.PAGE_DATATABLE = Symbol('page_dataTable');
exports.PAGE_AUTH = Symbol('page_auth');
exports.PAGE_ROLE = Symbol('page_role');
exports.PAGE_ACTIONS = Symbol('page_actions');
function Page(options) {
    var _a, _b, _c, _d;
    const isValidClass = (value) => {
        return typeof value === 'function' && value.prototype;
    };
    if ((options === null || options === void 0 ? void 0 : options.schema) && !isValidClass(options.schema)) {
        throw new Error(`Invalid schema provided: ${options.schema}`);
    }
    const defaultSchema = null;
    const defaultRouter = "";
    const defaultForm = "";
    const defaultOutput = "";
    const defaultTitle = "";
    const defaultShowTitle = true;
    const defaultShowBreadcrumb = true;
    const defaultDataTable = true;
    const defaultAuth = true;
    const defaultRole = "";
    const defaultActions = [
        "insert", "update", "delete",
        "export"
    ];
    const [schema, router, form, output, title, showTitle, showBreadcrumb, dataTable, auth, role, actions] = !options
        ? [
            defaultSchema,
            defaultRouter,
            defaultForm,
            defaultOutput,
            defaultTitle,
            defaultShowTitle,
            defaultShowBreadcrumb,
            defaultDataTable,
            defaultAuth,
            defaultRole,
            defaultActions
        ]
        : [
            options.schema || defaultSchema,
            options.router || defaultRouter,
            options.form || defaultForm,
            options.output || defaultOutput,
            options.title || defaultTitle,
            (_a = options.showTitle) !== null && _a !== void 0 ? _a : defaultShowTitle,
            (_b = options.showBreadcrumb) !== null && _b !== void 0 ? _b : defaultShowBreadcrumb,
            (_c = options.dataTable) !== null && _c !== void 0 ? _c : defaultDataTable,
            (_d = options.auth) !== null && _d !== void 0 ? _d : defaultAuth,
            options.role || defaultRole,
            options.actions || defaultActions
        ];
    return (target) => {
        Reflect.defineMetadata(exports.PAGE_SCHEMA, schema, target);
        Reflect.defineMetadata(exports.PAGE_ROUTER, router, target);
        Reflect.defineMetadata(exports.PAGE_FORM, form, target);
        Reflect.defineMetadata(exports.PAGE_OUTPUT, output, target);
        Reflect.defineMetadata(exports.PAGE_TITLE, title, target);
        Reflect.defineMetadata(exports.PAGE_SHOWTITLE, showTitle, target);
        Reflect.defineMetadata(exports.PAGE_SHOWBREADCRUMB, showBreadcrumb, target);
        Reflect.defineMetadata(exports.PAGE_DATATABLE, dataTable, target);
        Reflect.defineMetadata(exports.PAGE_AUTH, auth, target);
        Reflect.defineMetadata(exports.PAGE_ROLE, role, target);
        Reflect.defineMetadata(exports.PAGE_ACTIONS, actions, target);
    };
}
//# sourceMappingURL=page.decorator.js.map