import { ViewSchema } from "../abstracts";
import { ViewElement, ViewTab, ParsedContract } from "../interfaces";
export declare class VueformSchema extends ViewSchema {
    name: string;
    ext: string;
    components: {
        input: {
            tag: string;
            docs: string;
            props: {
                "input-type": string;
                mask: string;
                autocomplete: string;
                loading: string;
                placeholder: string;
                "force-numbers": string;
            };
        };
        textarea: {
            tag: string;
            docs: string;
            props: {
                autogrow: string;
                rows: string;
            };
        };
        editor: {
            tag: string;
            docs: string;
            props: {
                accept: string;
                "accept-mimes": string;
                endpoint: string;
                method: string;
                "hide-tools": string;
            };
        };
        phone: {
            tag: string;
            docs: string;
            props: {
                include: string;
                exclude: string;
                unmask: string;
                "allow-incomplete": string;
                autocomplete: string;
                loading: string;
            };
        };
        checkbox: {
            tag: string;
            docs: string;
            props: {
                text: string;
                "true-value": string;
                "false-value": string;
                align: string;
                standalone: string;
            };
        };
        checkboxgroup: {
            tag: string;
            docs: string;
            props: {
                items: string;
                disables: string;
                "clear-on-refetch": string;
            };
        };
        radio: {
            tag: string;
            docs: string;
            props: {
                "radio-name": string;
                "radio-value": string;
                text: string;
                align: string;
                standalone: string;
            };
        };
        radiogroup: {
            tag: string;
            docs: string;
            props: {
                items: string;
                disables: string;
                "clear-on-refetch": string;
            };
        };
        toggle: {
            tag: string;
            docs: string;
            props: {
                text: string;
                labels: string;
                "true-value": string;
                "false-value": string;
                "extend-options": string;
                align: string;
                standalone: string;
            };
        };
        select: {
            tag: string;
            docs: string;
            props: {
                native: string;
                items: string;
                "label-prop": string;
                "value-prop": string;
                "data-key": string;
                "search-param": string;
                search: string;
                "track-by": string;
                strict: string;
                create: string;
                "append-new-option": string;
                "add-option-on": string;
                "allow-absent": string;
                object: string;
                limit: string;
                groups: string;
                "group-label": string;
                "group-options": string;
                "group-hide-empty": string;
                "open-direction": string;
                "append-to-body": string;
                "append-to": string;
                "can-deselect": string;
                "can-clear": string;
                "close-on-select": string;
                "close-on-deselect": string;
                "clear-on-refetch": string;
                delay: string;
                "min-chars": string;
                "resolve-on-load": string;
                "filter-results": string;
                "clear-on-search": string;
                caret: string;
                truncate: string;
                loading: string;
                "no-options-text": string;
                "no-results-text": string;
                autocomplete: string;
                "input-type": string;
                "extend-options": string;
            };
        };
        button: {
            tag: string;
            docs: string;
            props: {
                "button-label": string;
                "button-type": string;
                "button-class": string;
                loading: string;
                href: string;
                target: string;
                resets: string;
                submits: string;
                secondary: string;
                danger: string;
                full: string;
                align: string;
            };
        };
        static: {
            tag: string;
            docs: string;
            props: {
                content: string;
                wrap: string;
                tag: string;
                allowHtml: string;
                href: string;
                target: string;
                src: string;
                alt: string;
                title: string;
                width: string;
                height: string;
                align: string;
                top: string;
                bottom: string;
            };
        };
        multiselect: {
            tag: string;
            docs: string;
            props: {
                items: string;
                "label-prop": string;
                "value-prop": string;
                "search-param": string;
                "track-by": string;
                autocomplete: string;
                "can-remove": string;
                "can-create": string;
                "can-clear": string;
                strict: string;
                "max-items": string;
                groups: string;
                "group-label": string;
                "group-options": string;
                "append-to-body": string;
                "open-direction": string;
                delay: string;
                "min-chars": string;
                "resolve-on-load": string;
                "filter-results": string;
                "clear-on-search": string;
                loading: string;
                "no-options-text": string;
                "no-results-text": string;
                placeholder: string;
            };
        };
        tags: {
            tag: string;
            docs: string;
            props: {
                items: string;
                "label-prop": string;
                "value-prop": string;
                "add-option-on": string;
                autocomplete: string;
                "search-param": string;
                "can-remove": string;
                "can-create": string;
                "can-clear": string;
                strict: string;
                "max-items": string;
                native: string;
                "append-to-body": string;
                groups: string;
                "group-label": string;
                "group-options": string;
                "clear-on-search": string;
                loading: string;
                "no-options-text": string;
                "no-results-text": string;
                "input-type": string;
                placeholder: string;
            };
        };
        date: {
            tag: string;
            docs: string;
            props: {
                value: string;
                format: string;
                "display-format": string;
                "min-date": string;
                "max-date": string;
                "start-week-on": string;
                locale: string;
                inline: string;
                range: string;
                multiple: string;
                "week-numbers": string;
                "disabled-dates": string;
                "highlighted-dates": string;
                time: string;
                "time-format": string;
                "time-interval": string;
                "time-disabled": string;
                "time-min": string;
                "time-max": string;
                placeholder: string;
            };
        };
        dates: {
            tag: string;
            docs: string;
            props: {
                values: string;
                format: string;
                "display-format": string;
                "min-date": string;
                "max-date": string;
                "start-week-on": string;
                locale: string;
                inline: string;
                range: string;
                multiple: string;
                "week-numbers": string;
                "disabled-dates": string;
                "highlighted-dates": string;
                time: string;
                "time-format": string;
                "time-interval": string;
                "time-disabled": string;
                "time-min": string;
                "time-max": string;
                placeholder: string;
            };
        };
        slider: {
            tag: string;
            docs: string;
            props: {
                value: string;
                min: string;
                max: string;
                step: string;
                format: string;
                tooltip: string;
                "tooltip-format": string;
                range: string;
                vertical: string;
                ticks: string;
                "ticks-values": string;
                "ticks-labels": string;
                "ticks-tooltip": string;
                "ticks-tooltip-format": string;
                "snap-to-ticks": string;
                track: string;
                "track-style": string;
                "track-class": string;
                disabled: string;
                placeholder: string;
            };
        };
        file: {
            tag: string;
            docs: string;
            props: {
                value: string;
                endpoint: string;
                method: string;
                accept: string;
                multiple: string;
                "max-files": string;
                "max-size": string;
                "auto-upload": string;
                "chunk-size": string;
                headers: string;
                params: string;
                "response-parse": string;
                "response-file-url": string;
                "response-error": string;
                disabled: string;
                loading: string;
                placeholder: string;
            };
        };
        multifile: {
            tag: string;
            docs: string;
            props: {
                value: string;
                endpoint: string;
                method: string;
                accept: string;
                multiple: string;
                "max-files": string;
                "max-size": string;
                "auto-upload": string;
                "chunk-size": string;
                headers: string;
                params: string;
                "response-parse": string;
                "response-file-url": string;
                "response-error": string;
                disabled: string;
                loading: string;
                placeholder: string;
            };
        };
        location: {
            tag: string;
            docs: string;
            props: {
                value: string;
                provider: string;
                "provider-options": string;
                "search-options": string;
                "marker-options": string;
                "map-options": string;
                autocomplete: string;
                loading: string;
                placeholder: string;
                disabled: string;
                readonly: string;
                geolocation: string;
                "geolocation-options": string;
                center: string;
                zoom: string;
                bounds: string;
                height: string;
                width: string;
                language: string;
                regions: string;
                types: string;
                "enable-geocoding": string;
            };
        };
        group: {
            tag: string;
            docs: string;
            props: {
                name: string;
                label: string;
                description: string;
                inline: string;
                columns: string;
                collapsible: string;
                collapsed: string;
                "collapsible-icon": string;
                "collapsible-toggle-position": string;
                "collapsible-toggle-alignment": string;
                slots: string;
                "add-classes": string;
                "add-class": string;
                "remove-classes": string;
                "remove-class": string;
                "replace-classes": string;
                "replace-class": string;
                "override-classes": string;
                "override-class": string;
            };
        };
        object: {
            tag: string;
            docs: string;
            props: {
                name: string;
                label: string;
                description: string;
                inline: string;
                columns: string;
                collapsible: string;
                collapsed: string;
                "collapsible-icon": string;
                "collapsible-toggle-position": string;
                "collapsible-toggle-alignment": string;
                value: string;
                slots: string;
                "add-classes": string;
                "add-class": string;
                "remove-classes": string;
                "remove-class": string;
                "replace-classes": string;
                "replace-class": string;
                "override-classes": string;
                "override-class": string;
            };
        };
        list: {
            tag: string;
            docs: string;
            props: {
                name: string;
                label: string;
                description: string;
                inline: string;
                columns: string;
                collapsible: string;
                collapsed: string;
                "collapsible-icon": string;
                "collapsible-toggle-position": string;
                "collapsible-toggle-alignment": string;
                items: string;
                "item-label-prop": string;
                "item-value-prop": string;
                sortable: string;
                removable: string;
                addable: string;
                value: string;
                slots: string;
                "add-classes": string;
                "add-class": string;
                "remove-classes": string;
                "remove-class": string;
                "replace-classes": string;
                "replace-class": string;
                "override-classes": string;
                "override-class": string;
            };
        };
        hidden: {
            tag: string;
            docs: string;
            props: {
                name: string;
                value: string;
                id: string;
            };
        };
        captcha: {
            tag: string;
            docs: string;
            props: {
                sitekey: string;
                theme: string;
                size: string;
                tabindex: string;
                callback: string;
                expiredCallback: string;
                errorCallback: string;
            };
        };
        signature: {
            tag: string;
            docs: string;
            props: {
                "background-color": string;
                "pen-color": string;
                "pen-width": string;
                height: string;
                width: string;
                "save-button": string;
                "clear-button": string;
                "save-button-label": string;
                "clear-button-label": string;
            };
        };
        generic: {
            tag: string;
            docs: string;
            props: {
                tag: string;
                text: string;
                html: string;
                classes: string;
                attrs: string;
            };
        };
    };
    genericAttrs: {
        id: string;
        name: string;
        maxlength: string;
        addons: string;
        label: string;
        readonly: string;
        disabled: string;
        attrs: string;
        floating: string;
        info: string;
        infoPosition: string;
        description: string;
        before: string;
        between: string;
        after: string;
        default: string;
        formatData: string;
        formatLoad: string;
        submit: string;
        rules: string;
        fieldName: string;
        debounce: string;
        messages: string;
        displayErrors: string;
        conditions: string;
        columns: string;
        inline: string;
        size: string;
        view: string;
        views: string;
        addClasses: string;
        addClass: string;
        removeClasses: string;
        removeClass: string;
        replaceClasses: string;
        replaceClass: string;
        overrideClasses: string;
        overrideClass: string;
        templates: string;
        presets: string;
        slots: string;
    };
    parser(contract: ParsedContract, components: Record<string, ViewElement>, tabs?: Array<ViewTab>): string;
}
