"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalesService = void 0;
const class_validator_1 = require("class-validator");
const class_transformer_1 = require("class-transformer");
const core_1 = require("@cmmv/core");
const repository_1 = require("@cmmv/repository");
const locales_model_1 = require("../models/locales.model");
const locales_entity_1 = require("../entities/locales.entity");
let LocalesService = class LocalesService extends core_1.AbstractService {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "name", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: "locales"
        });
    }
    getAll(queries, req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                core_1.Telemetry.start('LocalesService::GetAll', req === null || req === void 0 ? void 0 : req.requestId);
                let result = yield repository_1.Repository.findAll(locales_entity_1.LocalesEntity);
                core_1.Telemetry.end('LocalesService::GetAll', req === null || req === void 0 ? void 0 : req.requestId);
                return result;
            }
            catch (e) {
                return null;
            }
        });
    }
    getById(id, req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                core_1.Telemetry.start('LocalesService::GetById', req === null || req === void 0 ? void 0 : req.requestId);
                let item = yield repository_1.Repository.findBy(locales_entity_1.LocalesEntity, { id });
                core_1.Telemetry.end('LocalesService::GetById', req === null || req === void 0 ? void 0 : req.requestId);
                if (!item)
                    throw new Error('Item not found');
                return item;
            }
            catch (e) {
                return null;
            }
        });
    }
    add(item, req) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
                try {
                    core_1.Telemetry.start('LocalesService::Add', req === null || req === void 0 ? void 0 : req.requestId);
                    let newItem = (0, class_transformer_1.plainToClass)(locales_model_1.Locales, item, {
                        exposeUnsetFields: false,
                        enableImplicitConversion: true
                    });
                    newItem = this.removeUndefined(newItem);
                    delete newItem._id;
                    const errors = yield (0, class_validator_1.validate)(newItem, {
                        forbidUnknownValues: false,
                        skipMissingProperties: true,
                        stopAtFirstError: true,
                    });
                    if (errors.length > 0) {
                        core_1.Telemetry.end('TaskService::Add', req === null || req === void 0 ? void 0 : req.requestId);
                        reject(errors);
                    }
                    else {
                        let result = yield repository_1.Repository.insert(locales_entity_1.LocalesEntity, newItem);
                        core_1.Telemetry.end('TaskService::Add', req === null || req === void 0 ? void 0 : req.requestId);
                        resolve(result);
                    }
                }
                catch (e) {
                    core_1.Telemetry.end('TaskService::Add', req === null || req === void 0 ? void 0 : req.requestId);
                    console.log(e);
                    reject(e);
                }
            }));
        });
    }
    update(id, item, req) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
                try {
                    core_1.Telemetry.start('LocalesService::Update', req === null || req === void 0 ? void 0 : req.requestId);
                    let updateItem = (0, class_transformer_1.plainToClass)(locales_model_1.Locales, item, {
                        exposeUnsetFields: false,
                        enableImplicitConversion: true
                    });
                    updateItem = this.removeUndefined(updateItem);
                    delete updateItem._id;
                    const errors = yield (0, class_validator_1.validate)(updateItem, {
                        forbidUnknownValues: false,
                        skipMissingProperties: true,
                        stopAtFirstError: true
                    });
                    if (errors.length > 0) {
                        core_1.Telemetry.end('TaskService::Add', req === null || req === void 0 ? void 0 : req.requestId);
                        reject(errors);
                    }
                    else {
                        const result = yield repository_1.Repository.update(locales_entity_1.LocalesEntity, id, updateItem);
                        core_1.Telemetry.end('TaskService::Add', req === null || req === void 0 ? void 0 : req.requestId);
                        resolve(result);
                    }
                }
                catch (e) {
                    core_1.Telemetry.end('LocalesService::Update', req === null || req === void 0 ? void 0 : req.requestId);
                    console.log(e);
                    reject(e);
                }
            }));
        });
    }
    delete(id, req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                core_1.Telemetry.start('LocalesService::Delete', req === null || req === void 0 ? void 0 : req.requestId);
                const result = yield repository_1.Repository.delete(locales_entity_1.LocalesEntity, id);
                core_1.Telemetry.end('LocalesService::Delete', req === null || req === void 0 ? void 0 : req.requestId);
                return { success: result.affected > 0, affected: result.affected };
            }
            catch (e) {
                return { success: false, affected: 0 };
            }
        });
    }
};
exports.LocalesService = LocalesService;
exports.LocalesService = LocalesService = __decorate([
    (0, core_1.Service)("locales")
], LocalesService);
//# sourceMappingURL=locales.service.js.map