"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormBuilderTranspile = void 0;
const path = require("node:path");
const core_1 = require("@cmmv/core");
const decorators_1 = require("../decorators");
class FormBuilderTranspile {
    constructor() {
        Object.defineProperty(this, "logger", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new core_1.Logger('FormBuilderTranspile')
        });
    }
    run() {
        const env = core_1.Config.get('env');
        if (env === 'dev' || env === 'development' || env === 'build')
            this.processViews();
    }
    processViews() {
        const contracts = core_1.Scope.getArray('__contracts');
        contracts === null || contracts === void 0 ? void 0 : contracts.forEach((contract) => {
            if (contract.viewForm) {
                const parsedView = this.getFormMetadata(contract.viewForm);
                const viewParsed = parsedView.schema.parser(contract, parsedView.components, parsedView.tabs);
                parsedView.schema.generateOutput(path.resolve(parsedView.output), viewParsed);
            }
            if (contract.viewPage) {
                const parsedPage = this.getPageMetadata(contract.viewPage);
                console.log(parsedPage);
            }
        });
    }
    getFormMetadata(view) {
        const viewInstance = new view();
        const output = Reflect.getMetadata(decorators_1.FORM_OUTPUT, viewInstance.constructor);
        const schema = Reflect.getMetadata(decorators_1.FORM_SCHEMA, viewInstance.constructor);
        const generateHTML = Reflect.getMetadata(decorators_1.FORM_GENERATEHTML, viewInstance.constructor);
        const injectController = Reflect.getMetadata(decorators_1.FORM_INJECTCONTROLLER, viewInstance.constructor);
        const useRPC = Reflect.getMetadata(decorators_1.FORM_USERPC, viewInstance.constructor);
        return {
            schema: new schema(),
            components: viewInstance.components,
            tabs: viewInstance.tabs,
            output,
            generateHTML,
            injectController,
            useRPC
        };
    }
    getPageMetadata(page) {
        const pageInstance = new page();
        const schema = Reflect.getMetadata(decorators_1.PAGE_SCHEMA, pageInstance.constructor);
        const router = Reflect.getMetadata(decorators_1.PAGE_ROUTER, pageInstance.constructor);
        const form = Reflect.getMetadata(decorators_1.PAGE_FORM, pageInstance.constructor);
        const output = Reflect.getMetadata(decorators_1.PAGE_OUTPUT, pageInstance.constructor);
        const title = Reflect.getMetadata(decorators_1.PAGE_TITLE, pageInstance.constructor);
        const showTitle = Reflect.getMetadata(decorators_1.PAGE_SHOWTITLE, pageInstance.constructor);
        const showBreadcrumb = Reflect.getMetadata(decorators_1.PAGE_SHOWBREADCRUMB, pageInstance.constructor);
        const dataTable = Reflect.getMetadata(decorators_1.PAGE_DATATABLE, pageInstance.constructor);
        const auth = Reflect.getMetadata(decorators_1.PAGE_AUTH, pageInstance.constructor);
        const role = Reflect.getMetadata(decorators_1.PAGE_ROLE, pageInstance.constructor);
        const actions = Reflect.getMetadata(decorators_1.PAGE_ACTIONS, pageInstance.constructor);
        return {
            schema: new schema(),
            router,
            form,
            output,
            title,
            showTitle,
            showBreadcrumb,
            dataTable: (dataTable) ? pageInstance.dataTable : null,
            auth,
            role,
            actions,
        };
    }
}
exports.FormBuilderTranspile = FormBuilderTranspile;
//# sourceMappingURL=formbuilder.transpiler.js.map